pygeodesy.solveBase._SolveBase

Package pygeodesy :: Module solveBase :: Class _SolveBase |
[frames] | no frames]

# Class _SolveBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
              _SolveCapsBase --+
                               |
                              _SolveBase

Known Subclasses:
  - _Solve3Base

(INTERNAL) Base class for `_SolveBase` and `_SolveLineBase`.

Instance Methods
toStr(self, prec=6, sep=', ', **other) Return this instance as string. |
Inherited from `_SolveCapsBase`: `invokat`, `invoke`, `linelimit` Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
| reverse2 Get the `azi2` direction (`bool`).
| unroll Get the `lon2` unroll'ing (`bool`).
Inherited from `_SolveCapsBase`: `Exact`, `a`, `b`, `datum`, `ellipsoid`, `f`, `flattening`, `invokation`, `prec`, `status`, `verbose`, `version` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toStr (self, prec=6, sep=', ', **other) |
Return this instance as string. Arguments: `prec_sep` - Keyword argumens `prec=6` and `sep=", "` for the `float` `prec`ision, number of decimal digits (0..9) and the `sep`arator string to join. Trailing zero decimals are stripped for `prec` values of 1 and above, but kept for negative `prec` values. Overrides: named._Named.toStr

Property Details

### reverse2 Get the `azi2` direction (`bool`). Get method: reverse2(self) - Get the `azi2` direction (`bool`). Set method: reverse2(self, reverse2) - Set the direction for `azi2` (`bool`), if `True` reverse `azi2`. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### unroll Get the `lon2` unroll'ing (`bool`). Get method: unroll(self) - Get the `lon2` unroll'ing (`bool`). Set method: unroll(self, unroll) - Set unroll'ing for `lon2` (`bool`), if `True` unroll `lon2`, otherwise don't. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.